<#
    Part of Onevinn AB Web Services (Samples)
    Version: 2.1
    Author: Johan Schrewelius
    Date: 2021-01-29
#>

[string]$URI = "http://<server.domain.com>/onevinnWS/onevinnws.asmx"
[string]$UsrName = "<Domain\User>"
[string]$UsrPW = "<Password>"

try {

    $Mac = (Get-WmiObject win32_networkadapterconfiguration | Where { $_.DHCPEnabled -eq $true -and $_.IPAddress -ne $null } | select macaddress).macaddress

    if (!$URI.ToLower().EndsWith("?wsdl")) {
        $URI = $URI.TrimEnd("/") + "?wsdl"
    }

    $secpasswd = ConvertTo-SecureString "$UsrPW" -AsPlainText -Force
    $creds = New-Object System.Management.Automation.PSCredential ("$UsrName", $secpasswd)

    $response = Invoke-WebRequest -Uri $URI -Method Get -UseBasicParsing -Credential $creds -TimeoutSec 120

    if ($response.StatusCode -eq 200) {
        $tempFile = New-TemporaryFile
        $response.Content | Out-File -FilePath $tempFile -Encoding utf8 -Force
        $zip = New-WebServiceProxy -Uri $tempFile.FullName -Namespace eklient.it -Credential $creds
        $zip.Timeout = 200000
        $tempFile | Remove-Item -Force -EA SilentlyContinue
    }
    else {
        Write-Output "[ERROR] Failed to retrieve WSDL description from web service."
        exit 1
    }

    # Invoke Web Service

    $Count = $zip.DeleteUnKnownSystem($Mac)

    if($Count -gt 0) {
        Write-Host "Deleting Unknown Object in SCCM"
        Start-Sleep -Milliseconds 10000
    }
}
catch {
    Write-Output "$_.Exception.Message"
    exit 1
}