<#
    Part of Onevinn AB Web Services (Samples)
    Version: 2.1
    Author: Johan Schrewelius
    Date: 2021-01-29
#>

# Configuration for AD group filtering (Applications) #################

[string]$SiteCode = "<SiteCode>"
[string]$Prefix = "A."
[string]$InstallSuffix = ".i"
[string]$UnInstallSuffix = ".u"
[Bool]$RemovePrefix = $true
[bool]$IncludeComputerGroups = $true
[bool]$IncludeUserApps = $true

# Don't touch #########################################################

try {
    $tsenv = New-Object -COMObject Microsoft.SMS.TSEnvironment

    [string]$URI = $tsenv.Value("OWS-URL")
    [string]$UsrName = $tsenv.Value("OWS-UsrName")
    [string]$UsrPW = $tsenv.Value("OSD-UsrPW")
    [string]$CompName = $tsenv.Value("OSDComputerName")
    [string]$CompUUID = $tsenv.Value("_SMSTSSmbiosGuid")
    [string]$CompMAC = (Get-WmiObject -Namespace 'root\CIMV2' -Class 'Win32_NetworkAdapter' -Filter "NetConnectionStatus = 2").MACAddress

    if(!$CompName) {
        $CompName = $tsenv.Value("_SMSTSMachineName")
    }

    $secpasswd = ConvertTo-SecureString "$UsrPW" -AsPlainText -Force
    $creds = New-Object System.Management.Automation.PSCredential ("$UsrName", $secpasswd)

    if (!$URI.ToLower().EndsWith("?wsdl")) {
        $URI = $URI.TrimEnd("/") + "?wsdl"
    }

    $response = Invoke-WebRequest -Uri $URI -Method Get -UseBasicParsing -Credential $creds -TimeoutSec 120

    if ($response.StatusCode -eq 200) {
        $tempFile = New-TemporaryFile
        $response.Content | Out-File -FilePath $tempFile -Encoding utf8 -Force
        $zip = New-WebServiceProxy -Uri $tempFile.FullName -Namespace eklient.it -Credential $creds
        $zip.Timeout = 200000
        $tempFile | Remove-Item -Force -EA SilentlyContinue
    }
    else {
        Write-Output "[ERROR] Failed to retrieve WSDL description from web service."
        exit 1
    }
}
catch
{
    Write-Output "$_.Exception.Message"
    exit 1
}
